#[non_exhaustive]pub enum EnvPolicy {
Empty,
AllowList(Vec<String>),
InheritAll,
}Expand description
Environment variable handling for command execution.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Empty
Start from an empty environment and use only CommandRequest::env.
AllowList(Vec<String>)
Inherit only listed keys from the parent process, then apply
CommandRequest::env.
InheritAll
Inherit the full parent environment. This is not the default because it can leak secrets.