WatchReceiver

Struct WatchReceiver 

pub struct WatchReceiver { /* private fields */ }
The receive end of a watch channel: observes value changes.

Does not implement Clone — a single receive end can only be driven by one waiter at a time (serialized by an internal lock). For multiple observers, call subscribe on the WatchChannel separately for each.

Implementations

Source

impl WatchReceiver

pub async fn recv(&self) -> Result<IncomingMessage, ChannelError>

Waits for a change and takes the latest value.

Errors

Returns ChannelError::Closed when the sender (WatchChannel) has been dropped.

Cancellation semantics

Being cancelled while waiting has no side effects: watch is not a queue and has no “take one item” concept, the next recv starts from the latest value and keeps waiting for the next change.