#[non_exhaustive]pub enum Observation {
Model(ModelObservation),
Effect(EffectObservation),
Effects(Vec<EffectObservation>),
}Expand description
Observation fed back to a step-wise agent kernel.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Model(ModelObservation)
Successful model response.
Effect(EffectObservation)
Effect observation produced by an outer harness.
Effects(Vec<EffectObservation>)
Batch effect observations produced by an outer harness.
This is the companion to AgentAction::RequestEffects. The outer
runtime may execute the requests sequentially or in parallel, then
feeds the completed set back to the kernel as one step.